==> hs-blaze-builder-enumerator-0.2.0.2_1.tbz: lib/ghc-7.0.3/cabal/blaze-builder-enumerator-0.2.0.2/register.sh <==
#!/bin/sh
echo 'name: blaze-builder-enumerator
version: 0.2.0.2
id: blaze-builder-enumerator-0.2.0.2-a2c138b57b93ecd83050c285847b8423

license: BSD3
copyright: Copyright (c) 2010, 2011 Simon Meier
           original package by Thomas Sutton <me@thomas-sutton.id.au>
maintainer: Simon Meier <iridcode@gmail.com>
stability: Experimental
homepage: https://github.com/meiersi/blaze-builder-enumerator
package-url:
description: This package integrates the builders from the blaze-builder package with
             the enumerator package. It provides infrastructure and enumeratees for
             incrementally executing builders and pass the filled chunks to a bytestring
             iteratee.
category: Data, Enumerator
author: Simon Meier <iridcode@gmail.com>
exposed: True
exposed-modules: Blaze.ByteString.Builder.Enumerator
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/blaze-builder-enumerator-0.2.0.2
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/blaze-builder-enumerator-0.2.0.2
              /usr/local/lib
hs-libraries: HSblaze-builder-enumerator-0.2.0.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         blaze-builder-0.3.0.1-f04ac78deda4862ea589cfaee6d1e34d
         bytestring-0.9.1.10-8fbcae7fd1f192307195284611c786a2
         enumerator-0.4.13.1-92131084023a0b6405ad210fdae5d880
         transformers-0.2.2.0-a8a2dbba7d96131db605cf631ea0c8c4
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/blaze-builder-enumerator-0.2.0.2/html/blaze-builder-enumerator.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/blaze-builder-enumerator-0.2.0.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-blaze-builder-enumerator-0.2.0.3.tbz: lib/ghc-7.0.4/cabal/blaze-builder-enumerator-0.2.0.3/register.sh <==
#!/bin/sh
echo 'name: blaze-builder-enumerator
version: 0.2.0.3
id: blaze-builder-enumerator-0.2.0.3-b24ff070013d497186de8bd5302bd199

license: BSD3
copyright: Copyright (c) 2010, 2011 Simon Meier
           original package by Thomas Sutton <me@thomas-sutton.id.au>
maintainer: Simon Meier <iridcode@gmail.com>
stability: Experimental
homepage: https://github.com/meiersi/blaze-builder-enumerator
package-url:
description: This package integrates the builders from the blaze-builder package with
             the enumerator package. It provides infrastructure and enumeratees for
             incrementally executing builders and pass the filled chunks to a bytestring
             iteratee.
category: Data, Enumerator
author: Simon Meier <iridcode@gmail.com>
exposed: True
exposed-modules: Blaze.ByteString.Builder.Enumerator
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/blaze-builder-enumerator-0.2.0.3
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/blaze-builder-enumerator-0.2.0.3
              /usr/local/lib
hs-libraries: HSblaze-builder-enumerator-0.2.0.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         blaze-builder-0.3.1.0-19b8f4f8b5d83779c3b3e947a878bd26
         bytestring-0.9.1.10-8fbcae7fd1f192307195284611c786a2
         enumerator-0.4.18-ab0738621e39ac3ae083dbffa0d2022d
         transformers-0.2.2.0-a8a2dbba7d96131db605cf631ea0c8c4
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/blaze-builder-enumerator-0.2.0.3/html/blaze-builder-enumerator.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/blaze-builder-enumerator-0.2.0.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
